#
# spec file for package ghc-optparse-applicative
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global pkg_name optparse-applicative
%bcond_with tests
Name:           ghc-%{pkg_name}
Version:        0.15.1.0
Release:        bp153.1.20
Summary:        Utilities and combinators for parsing command line options
License:        BSD-3-Clause
URL:            https://hackage.haskell.org/package/%{pkg_name}
Source0:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/%{pkg_name}-%{version}.tar.gz
Source1:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/revision/1.cabal#/%{pkg_name}.cabal
BuildRequires:  ghc-Cabal-devel
BuildRequires:  ghc-ansi-wl-pprint-devel
BuildRequires:  ghc-process-devel
BuildRequires:  ghc-rpm-macros
BuildRequires:  ghc-transformers-compat-devel
BuildRequires:  ghc-transformers-devel
%if %{with tests}
BuildRequires:  ghc-QuickCheck-devel
BuildRequires:  ghc-bytestring-devel
%endif

%description
Optparse-applicative is a haskell library for parsing options on the command
line, providing a powerful applicative interface for composing these options.

optparse-applicative takes care of reading and validating the arguments passed
to the command line, handling and reporting errors, generating a usage line, a
comprehensive help screen, and enabling context-sensitive bash completions.

See the included README for detailed instructions and examples, which is also
available on github <https://github.com/pcapriotti/optparse-applicative>.

%package devel
Summary:        Haskell %{pkg_name} library development files
Requires:       %{name} = %{version}-%{release}
Requires:       ghc-compiler = %{ghc_version}
Requires(post): ghc-compiler = %{ghc_version}
Requires(postun): ghc-compiler = %{ghc_version}

%description devel
This package provides the Haskell %{pkg_name} library development
files.

%prep
%setup -q -n %{pkg_name}-%{version}
cp -p %{SOURCE1} %{pkg_name}.cabal

%build
%ghc_lib_build

%install
%ghc_lib_install

%check
%cabal_test

%post devel
%ghc_pkg_recache

%postun devel
%ghc_pkg_recache

%files -f %{name}.files
%license LICENSE

%files devel -f %{name}-devel.files
%doc CHANGELOG.md README.md

%changelog
* Thu May  7 2020 Peter Simons <psimons@suse.com>
- Update Cabal file to get more accurate dependency information.
* Fri Nov  8 2019 Peter Simons <psimons@suse.com>
- Drop obsolete group attributes.
* Fri Sep 13 2019 psimons@suse.com
- Update optparse-applicative to version 0.15.1.0.
  Upstream has edited the change log file since the last release in
  a non-trivial way, i.e. they did more than just add a new entry
  at the top. You can review the file at:
  http://hackage.haskell.org/package/optparse-applicative-0.15.1.0/src/CHANGELOG.md
* Sat Jul  6 2019 psimons@suse.com
- Update optparse-applicative to version 0.15.0.0.
  Upstream has edited the change log file since the last release in
  a non-trivial way, i.e. they did more than just add a new entry
  at the top. You can review the file at:
  http://hackage.haskell.org/package/optparse-applicative-0.15.0.0/src/CHANGELOG.md
* Tue Jun 11 2019 Peter Simons <psimons@suse.com>
- Update Cabal file for more accurate build dependencies.
* Thu Oct  4 2018 psimons@suse.com
- Update optparse-applicative to version 0.14.3.0.
  [#]# Version 0.14.3.0 (03 Oct 2018)
  - Updated dependency bounds.
  - Fix tab completion with Commands being unreachable.
  - Clean ups and Documentation.
* Wed Jul 18 2018 psimons@suse.com
- Cosmetic: replace tabs with blanks, strip trailing white space,
  and update copyright headers with spec-cleaner.
* Mon May 14 2018 psimons@suse.com
- Update optparse-applicative to version 0.14.2.0.
  - Export `HasName`, `HasCompleter`, `HasValue`, and
    `HasMetavar` type classes.
  - Upgrade `str` and related builders to be polymorphic over
    `IsString`. This allows `Text` and `Bytestring` to be used
    naturally with `strOption` and `strArgument` and friends.
  * Note:* This change may require additional type signatures
    in cases where the reader was necessary for type
    inference.
  - Export public API explicitly from `Options.Applicative`
    instead of re-exporting other modules.
  * Note:* Minor changes to exports were made in conjunction
    to this change. `ParserHelp` no longer requires an
    an extra import, and some internally used functions
    from `Options.Applicative.Common` are no longer
    exported from the main module.
  - Add Zsh and Fish completions with rich descriptions for
    options and commands.
    Use "--zsh-completion-script" and "fish-completion-script"
    to generate scripts for these shells.
  - Fix bash completions with quoted sections, tilde expansions
    and completions after "--".
  - Add suggestions to error message when a user mistypes a
    command or option.
  - Add `style` builder, for styling option descriptions.
  - Improve error message for options when a required argument
    is not supplied.
  - Fix #242 regarding flags with long options, where a flag given
    a long option could be interpreted incorrectly.
  - Fix `noIntersperse` to be more like its namesakes in other
    libraries. When on, options will be accepted until an argument
    is passed, after which all options will be treated as positional
    arguments.
  - Add `forwardOptions` builder, which will allow unknown options
    and flags to be passed to an argument builder.
    This is useful to mixed parsing environments, or wrappers to
    other commands.
  - Add `Semigroup` instances for `Completer` and `Chunk`.
  - Forwards compatibility with `MonadFail` proposal.
* Thu Aug  3 2017 psimons@suse.com
- Updated with latest spec-cleaner version 0.9.8-8-geadfbbf.
* Tue Mar 14 2017 psimons@suse.com
- Update to version 0.13.2.0 with cabal2obs.
* Sun Feb 12 2017 psimons@suse.com
- Update to version 0.13.1.0 with cabal2obs.
* Sun Jul 10 2016 psimons@suse.com
- Update to version 0.12.1.0 revision 0 with cabal2obs.
* Wed Jan 20 2016 mimi.vx@gmail.com
- update to 0.12.1.0
  * Improve subparser contexts to improve usage error texts
  * Fixed bugs
* Wed Dec 30 2015 mimi.vx@gmail.com
- update to 0.12.0.0
  * Add "missing" error condition descriptions when required flags and arguments
    are not provided.
  * Allow multiple short flags to be concatenated together behind a single
    hyphen, e.g. "-xcf".
  * Updated dependency bounds on process and ansi-wl-pprint.
  * Add Show and Eq instances to some types for easier debugging.
  * Add defaultPrefs, a default preferences value
* Thu Nov 19 2015 mimi.vx@gmail.com
- initial commit
